#ifndef AVATARS_H
#define AVATARS_H

#include <qpixmap.h>
#include <qstring.h>
#include <qdatetime.h>

#include "xmpp.h"
#include "xmpp_tasks.h"
#include "xmpp_xmlcommon.h"

using namespace XMPP;

class PsiAccount;
class Avatar;
class JEP8Avatar;
class FileAvatar;
class ClientAvatar;


// Define this if you want JEP8 avatars. Warning: this costs bandwith.
#define JEP8_AVATARS

/******************************************************************************/

class AvatarFactory : public QObject
{
	Q_OBJECT

public:
	AvatarFactory(PsiAccount* pa);

	QPixmap getAvatar(const Jid& jid, const QString& resource);
//	void setHash(const Jid& jid, const QString& hash);
	PsiAccount* account() const
		{ return pa_; }
	QPixmap getSelfAvatar();

	void importManualAvatar(const Jid& j, const QString& fileName);

	static QString getAvatarsDir();
	static QString getCacheDir();
	static QString getManualDir();

signals:
	void avatarChanged(const Jid&);

public slots:
	void updateAvatar(const Jid&);

protected:
	Avatar* retrieveAvatar(const Jid& jid, const QString& resource);

private:
	QMap<QString,Avatar*> active_avatars_;
//	QMap<QString,JEP8Avatar*> jep8_avatars_;
	QMap<QString,FileAvatar*> file_avatars_;
	QMap<QString,ClientAvatar*> client_avatars_;
	PsiAccount* pa_;
};

/******************************************************************************/

class Avatar
{
public:
	Avatar();
	virtual ~Avatar();
	virtual QPixmap getPixmap()
		{ return pixmap(); }
	virtual bool isEmpty()
		{ return getPixmap().isNull(); }
//	virtual const QString& hash();
	virtual const QString& encode();
	virtual const QString& mimetype();

protected:
	virtual const QPixmap& pixmap() const 
		{ return pixmap_; }
	virtual void setPixmap(const QPixmap& pixmap)
		{ pixmap_ = pixmap; /*hash_ = "";*/ base64_ = ""; }

private:
	QPixmap pixmap_;
//	QString hash_;
	QString base64_;
	QString mimeType_;
};


#endif
